@@ -21,8 +21,8 @@ col_new(View*v, char *arg)
 
 	findplace(wily, &min, &max);
 	tagt = text_alloc(0, false);
-	text_replaceutf(tagt, range(0,0),  columntools);
-	col = tile_new(H, min, max, MINCOLWIDTH, wily, tagt, 0);
+	text_replaceutf(tagt, nr,  columntools);
+	col = tile_new(H, min, max, MINWIDTH, wily, tagt, 0);
 	list_add(wily, col);
 }
 
