@@ -1,21 +1,22 @@
 #include "wily.h"
 
+/* global toggles */
 Bool 	show_dot_files = false;
 Bool 	autoindent_enabled = true;
 
-Path		wilydir;			/* cwd for wily process */
-View *	last_selection;		/* widget with most recent b1 click */
+/* cwd for wily process */
+Path		wilydir;
 
+/* widget with most recent b1 click */
+View *	last_selection;		
+
+/* "stop" characters for various text expansions.
+ * heuristic guesses only.
+ */
 char *notfilename = 	"!\"#%&'()*;<=>?@`[\\]^{|}";
 char *notinclude = 		"!#%&'()*;=?@`[\\]^{|}";
 char *notdoubleclick=	"!\"#$%&'()*+,-./:;<=>?@`[\\]^{|}~";
 char *notcommand=	"!\"#%&'()*;:=?@`[\\]^{}";
 char *notaddress=		"!\"%&'()+;<=>?@`[]{|}";
+
 char *whitespace = 		" \t\v\n";
-char *alnums = 
-"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789";
-
-/** Config. variables for Bjorn's changes to libframe **/
-int old_frame = false;
-int noisy = false;
-
