@@ -4,9 +4,45 @@
 enum {TSIZE=401};
 static Tile* placetable[TSIZE];	/* hashed array of column tiles */
 
+static Bool		iserror(char*label);
+static Bool		validcolumn(Tile*c);
+static unsigned long	hashpath(char *path);
+static Tile *			find(char *label);
+
+/* Save the window column for later lookup. */
+void
+placedcol(char*label, Tile *c) {
+	if (label && !iserror(label))
+		placetable[hashpath(label)] = c;
+}
+
+/* Return the column to use for a new window with label 'path' */
+Tile*
+findcol(char*label) {
+	Tile	*c;
+
+	if(!wily->down){
+		col_new(wily->tag,0);
+		return wily->down;
+	}
+
+	if(iserror(label))
+		return last_visible(wily->down, 0);
+
+	if (!(c= find(label))) {
+		c = biggest_visible(wily->down, 0);
+		assert(c);
+		placedcol(label, c);
+	}
+	return c;
+}
+
+/******************************************************
+	static functions
+******************************************************/
+
 static Bool
-iserror(char*label)
-{
+iserror(char*label) {
 	static char *errors = "+Errors";
 	int	elen = strlen(errors);
 	int	len = strlen(label);
@@ -36,14 +72,6 @@ hashpath(char *path)
 	return hash % TSIZE;
 }
 
-/* Save the window column for later lookup. */
-void
-placedcol(char*label, Tile *c)
-{
-	if (label && !iserror(label))
-		placetable[hashpath(label)] = c;
-}
-
 static Tile *
 find(char *label)
 {
@@ -56,24 +84,3 @@ find(char *label)
 	return 0;
 }
 
-/* Return the column to use for a new window with label 'path' */
-Tile*
-findcol(char*label)
-{
-	Tile	*c;
-
-	if(!wily->down){
-		col_new(wily->tag,0);
-		return wily->down;
-	}
-
-	if(iserror(label))
-		return last_visible(wily->down, 0);
-
-	if (!(c= find(label))) {
-		c = biggest_visible(wily->down, 0);
-		assert(c);
-		placedcol(label, c);
-	}
-	return c;
-}
