@@ -3,8 +3,7 @@
 
 /* Set 'cmin' and 'cmax' for any child of 'list'  */
 void
-setcminmax(Tile *list, int*cmin, int*cmax)
-{
+setcminmax(Tile *list, int*cmin, int*cmax) {
 	if(list) {
 		*cmin = (list->ori == V)? list->tag->r.max.y + tagheight:list->min;
 		*cmax = list->max;
@@ -16,8 +15,7 @@ setcminmax(Tile *list, int*cmin, int*cmax)
 
 /* Return the Rectangle to enclose 't' */
 Rectangle
-rectangle(Tile*t)
-{
+rectangle(Tile*t) {
 	if(t->ori==H) {
 		return Rect(t->min, t->up->tag->r.max.y, 
 				t->max, t->up->max);
@@ -30,14 +28,13 @@ rectangle(Tile*t)
 
 /* Return a point somewhere in the middle of 'tile's button */
 Point
-buttonpos(Tile*tile)
-{
+buttonpos(Tile*tile) {
 	return add(tile->tag->r.min, Pt(SCROLLWIDTH/2, SCROLLWIDTH/2));
 }
 
+/* Return the tile containing p (or 0) */
 Tile*
-point2tile(Tile *tile, Point p)
-{
+point2tile(Tile *tile, Point p) {
 	int	pos;
 	Tile	*t;
 
@@ -54,9 +51,9 @@ point2tile(Tile *tile, Point p)
 	return tile;
 }
 
+/* Return the view containing p (or 0) */
 View *
-point2view(Point p)
-{
+point2view(Point p) {
 	Tile	*t;
 	View	*v;
 
