@@ -15,20 +15,22 @@ struct Text {
 	View		*v;			/* list of views of this text */
 	Bool		needsbackup;	/* this text can become dirty */
 
-	/* temporary buffer for search operations */
-	Rune	getcbuf[NGETC];	
-	int		ngetc;		
-	int		getci;		
-	ulong	getcp;		
+	ulong	pos;			/* position for regexp search engine */
 
 	Undo	*did,*undone, *mark;
 	enum {NoUndo, StartUndo, MoreUndo} undoing;
 };
 #define TEXT_ISTAG(t) (	!(t)->isbody	)
 #define TEXT_ISWINTAG(t) ((t)->v && (t)->v->win && TEXT_ISTAG(t))
+#define TCHAR(t,p) ((p)<(t)->gap.p0) ? (t)->text[(p)] : (t)->text[(p) + RLEN((t)->gap)]
 
-/* Get next rune, going forwards */
-#define	Tgetc(t)  ((--(t)->ngetc<0)? Tgetcload(t, (t)->getcp) : (t)->getcbuf[(t)->getcp++, (t)->getci++])
 
-/* Get next rune, going backwards */
-#define	Tbgetc(t) (((t)->getci<=0)? Tbgetcload(t, (t)->getcp) : (t)->getcbuf[--(t)->getcp, --(t)->getci])
+/* Get next rune, going forwards/backwards */
+#define	Tgetc(t)  ( ((t)->pos<(t)->gap.p0) ? ((t)->text[(t)->pos++] ) : (((t)->pos < (t)->length) ? (t)->text[(t)->pos++ + RLEN((t)->gap)] : -1))
+
+#define Tbgetc(tp) ( ((tp)->pos > (tp)->gap.p0) ? \
+	(tp)->text[--(tp)->pos + RLEN((tp)->gap)] : \
+	( (tp)->pos ? (tp)->text[--(tp)->pos] : -1) )
+
+#define Tbgetcset(t,p) ( (t)->pos = (p))
+#define Tgetcset(t,p) ((t)->pos = (p))
