@@ -33,8 +33,7 @@ win_del(Tile *w)
 
 /* Return the window associated with 'tile', or 0. */
 Tile*
-tile_win(Tile*tile)
-{
+tile_win(Tile*tile) {
 	return (tile && tile->body) ? tile : 0;
 }
 
@@ -63,7 +62,6 @@ win_anchor(Tile*w, char *arg)
 	if(arg) {
 		/* line address */
 		Range sel;
-		Text *t;
 		int	line;
 		View *v;
 		
